# zoo - versatile objects management
# Copyright (C) 2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import functools

from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class ZooNanterreConfig(AppConfig):
    name = 'zoo.zoo_nanterre'
    verbose_name = _('Nanterre')

    def get_entity_actions(self):
        from . import utils, fragments

        def synchronize(application, modeladmin, request, queryset):
            qs = queryset.filter(schema__slug=utils.INDIVIDU_ENT)
            messages = list(fragments.synchronize([application], qs))

        actions = {}
        for application in utils.get_applications(rsu_ws_url=True):
            app_dfn = utils.get_application(application)
            name = u'Synchroniser %s' % app_dfn['name']
            actions[name] = (functools.partial(synchronize, application), name, name)
        return actions
