# zoo - versatile objects management
# Copyright (C) 2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from zoo.zoo_data.models import Entity


def doublons(schema, *args):
    '''Search for duplicate entities based on a list of field paths'''
    qs = Entity.objects.filter(schema=schema)
    paths = schema.paths_to_strings()
    for arg in args:
        if arg not in paths:
            raise ValueError('%s is not a path to a string value' % arg)

    def value(item, path):
        for elt in path:
            item = item[elt]
        return item

    seen = set()
    for item in qs:
        if item.pk in seen:
            continue
        for arg in args:
            kwargs = {}
            for path in paths:
                kwargs['__'.join(path)] = value(item.content, path)
            for doublon in qs.exclude(pk=item.pk).content_search(schema, **kwargs):
                yield item, doublon
                seen.add(doublon.pk)
