# -*- coding: utf-8 -*-
#
# zoo - versatile objects management
# Copyright (C) 2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.views.generic import TemplateView
from django.db.transaction import non_atomic_requests
from django.db import connection

from . import forms


class Demo(TemplateView):
    template_name = 'zoo_nanterre/demo.html'

demo = Demo.as_view()


class Search(TemplateView):
    template_name = 'zoo_nanterre/search.html'

    def get_context_data(self, **kwargs):
        ctx = super(Search, self).get_context_data(**kwargs)
        form = forms.SearchForm(data=self.request.GET or None)
        ctx['form'] = form
        ctx['results'] = list(form.results()) if form.is_valid() else []
        return ctx


class ImportControl(TemplateView):
    template_name = 'zoo_nanterre/import_control.html'

    def get_context_data(self, **kwargs):
        ctx = super(ImportControl, self).get_context_data(**kwargs)
        c = connection.cursor()
        c.execute("SELECT count(e.id) from zoo_data_entity as e , zoo_meta_entityschema as s where "
                  " e.schema_id = s.id and s.slug = 'individu'")
        ctx['count'] = c.fetchone()[0]
        c.execute("SELECT count(e.id) from zoo_data_entity as e , zoo_meta_entityschema as s where "
                  " e.schema_id = s.id and s.slug = 'individu' and e.content->>'statut_legal' = 'majeur'")
        ctx['majeurs'] = c.fetchone()[0]
        c.execute("SELECT count(e.id) from zoo_data_entity as e , zoo_meta_entityschema as s where "
                  " e.schema_id = s.id and s.slug = 'individu' and e.content->>'statut_legal' = 'mineur'")
        ctx['mineurs'] = c.fetchone()[0]
        c.execute("SELECT count(e.content->'cles_de_federation'->'technocarte') from "
                  "zoo_data_entity as e")
        ctx['federations_technocarte'] = c.fetchone()[0]
        c.execute("SELECT count(e.content->'cles_de_federation'->'infor') from "
                  "zoo_data_entity as e")
        ctx['federations_infor'] = c.fetchone()[0]
        c.execute("SELECT count(e.content->'cles_de_federation'->'implicit') from "
                  "zoo_data_entity as e")
        ctx['federations_implicit'] = c.fetchone()[0]
        c.execute("SELECT count(e.content->'cles_de_federation'->'saga') from "
                  "zoo_data_entity as e")
        ctx['federations_saga'] = c.fetchone()[0]
        c.execute("SELECT count(e.content->'cles_de_federation'->'saga_tiers') from "
                  "zoo_data_entity as e")
        ctx['federations_saga_tiers'] = c.fetchone()[0]
        return ctx


search = non_atomic_requests(Search.as_view())

import_control = ImportControl.as_view()
